import Decimal from 'decimal.js';
type PriceFormatterProps = {
    price: number;
    fromSmallestUnit?: boolean;
    fromCurrency: {
        symbol: string;
        decimals: number;
    };
    toCurrency?: {
        symbol: string;
        decimals: number;
        mid: number;
    };
    negative?: boolean;
};
/**
 * Formats a given price according to the specified currency details and formatting rules,
 * optionally converting the price from a source currency to a target currency, while removing trailing zeros.
 *
 * @param {Object} params - The parameters for the price formatter.
 * @param {number} params.price - The price to be formatted.
 * @param {boolean} [params.fromSmallestUnit=false] - Indicates whether the price is provided in the smallest unit of the source currency.
 * @param {Object} params.fromCurrency - The source currency properties.
 * @param {string} params.fromCurrency.symbol - The symbol of the source currency.
 * @param {number} params.fromCurrency.decimals - The number of decimal places for the source currency.
 * @param {Object} [params.toCurrency] - The target currency properties. If provided, the price is converted to this currency.
 * @param {string} params.toCurrency.symbol - The symbol of the target currency.
 * @param {number} params.toCurrency.decimals - The number of decimal places for the target currency.
 * @param {number} params.toCurrency.mid - The conversion rate from the source currency to the target currency.
 * @param {boolean} [params.negative=false] - If true, prefixes the formatted price with a negative sign.
 * @returns {string} The formatted price string.
 */
export declare const priceFormatter: ({ price, fromSmallestUnit, negative, fromCurrency, toCurrency, }: PriceFormatterProps) => string;
export declare const ensureDecimal: (value: number | Decimal) => Decimal;
export declare const convertBack: (value: Decimal, decimals: number | Decimal) => number;
export declare const multiplyByDecimals: (value: Decimal, decimals: number | Decimal) => Decimal;
/**
 * Divide a value by decimals and convert back to the original unit, but if `returnSmallestUnit` is true, return the
 * smallest unit instead or main unit.
 * @param value
 * @param decimals
 * @param returnSmallestUnit
 */
export declare const divideConvertBackSmallestUnit: (value: Decimal, decimals: number | Decimal, returnSmallestUnit?: boolean) => number;
export {};
